/**
 * $Id: sc_queue.c,v 1.5 2004/09/04 07:08:01 jklein Exp $
 * $Author: jklein $
 * $Log: sc_queue.c,v $
 * Revision 1.5  2004/09/04 07:08:01  jklein
 * fixed "const spointer" to "sconstpointer".
 *
 * Revision 1.4  2004/08/05 13:54:30  jklein
 * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
 *
 * Revision 1.3  2004/06/21 16:44:17  jklein
 * Added iterator.
 *
 */


#include <scale/queue.h>


spointer
s_queue_dequeue(squeue_t *queue)
{
	if (s_queue_size((slist_t *)queue) == 0)
		return NULL;

	return s_list_remove((slist_t *)queue, 0);
}


spointer
s_queue_front(squeue_t *queue)
{
	if (s_queue_size((slist_t *)queue) == 0)
		return NULL;
	
	return s_list_get((slist_t *)queue, 0);
}


